==> JOB-3.1.2.tar.gz: JOB-3.1.2/event/demo/PullServer.java <==
// **********************************************************************
//
// Copyright (c) 1998
// Object-Oriented Concepts, Inc.
// Billerica, MA, USA
//
// Copyright (c) 1998
// Object-Oriented Concepts GmbH
// Ettlingen, Germany
//
// All Rights Reserved
//
// **********************************************************************

package event;

import org.omg.CORBA.*;
import org.omg.CosEventChannelAdmin.*;
import java.io.*;
import java.util.*;

public class PullServer
{
    public static void
    main(String args[])
    {
	Properties props = System.getProperties();
	props.put("org.omg.CORBA.ORBClass", "com.ooc.CORBA.ORB");
	props.put("org.omg.CORBA.ORBSingletonClass",
		  "com.ooc.CORBA.ORBSingleton");
	System.setProperties(props);

	try
	{
	    //
	    // Create ORB.
	    //
	    ORB orb = ORB.init(args, props);

	    //
	    // Filter options.
	    //
	    args = ((com.ooc.CORBA.ORB)orb).filter_options(args);
	    
	    //
	    // Create BOA.
	    //
	    BOA boa = ((com.ooc.CORBA.ORB)orb).BOA_init(args, props);

	    //
	    // Filter options.
	    //
	    args = ((com.ooc.CORBA.BOA)boa).filter_options(args);

	    ((com.ooc.CORBA.ORB)orb).conc_model(
		com.ooc.CORBA.ORB.ConcModel.ConcModelThreaded);
	    ((com.ooc.CORBA.BOA)boa).conc_model(
		com.ooc.CORBA.BOA.ConcModel.ConcModelThreadPerClient);

	    //
	    // Parse command line arguments.
	    //
	    boolean slow = false;
	    long timeout = 5;
	    boolean reg = true;
	    for(int i = 0; i < args.length; i++)
	    {
		if(args[i].equals("--help") || args[i].equals("-h"))
		{
		    usage();
		}
		else if(args[i].equals("-s") || args[i].equals("--slow"))
		{
		    slow = true;
		}
		else if(args[i].equals("-n") ||args[i].equals("--no-register"))
		{
		    reg = false;
		}
		else if(args[i].equals("-t") ||
			args[i].equals("--timeout"))
		{
		    if(i + 1 >= args.length)
		    {
			System.err.println("Argument expected for " + args[i]);
			System.exit(1);
		    }
		    try
		    {
			timeout = Long.parseLong(args[i+1]);
		    }
		    catch(NumberFormatException ex)
		    {
			System.err.println("Bad format for timeout: " +
					   args[i+1]);
			System.exit(1);
		    }
		    ++i;
		}
		else
		{
		    System.err.println("Unknown option `" + args[i] + "'");
		    usage();
		    System.exit(1);
		}
	    }
	    
	    //
	    // Get event channel.
	    //
	    org.omg.CORBA.Object obj = null;
	    
	    try
	    {
		obj = orb.resolve_initial_references("EventService");
	    }
	    catch(org.omg.CORBA.ORBPackage.InvalidName ex)
	    {
		System.err.println("Can't resolve `EventService'");
		System.exit(1);
	    }

	    if(obj == null)
	    {
		System.err.println("`EventService' is a nil object reference");
		System.exit(1);
	    }

	    EventChannel e = EventChannelHelper.narrow(obj);
	    if(e == null)
	    {
		System.err.println("`EventChannel' is not an EventChannel " +
				   "object reference");
		System.exit(1);
	    }

	    //
	    // Get ProxyPullConsumer.
	    //
	    SupplierAdmin supplierAdmin = e.for_suppliers();
	    ProxyPullConsumer consumer = supplierAdmin.obtain_pull_consumer();

	    //
	    // Connect implementation to ProxyPullConsumer.
	    //
	    PullSupplier_impl supplier = new PullSupplier_impl(consumer, slow);

	    //
	    // Connect the supplier to the ORB with the same name each
	    // time.
	    //
	    ((com.ooc.CORBA.ORB)orb).connect(supplier, "DefaultSupplier");

	    ((com.ooc.CORBA.BOA)boa).init_servers();

	    if(reg)
	    {
		try
		{
		    consumer.connect_pull_supplier(supplier);
		}
		catch(AlreadyConnected ex)
		{
		    ex.printStackTrace();
		    System.exit(1);
		}
		catch(TypeError ex)
		{
		    ex.printStackTrace();
		    System.exit(1);
		}
	    }

	    //
	    // Run implementation.
	    //
	    if(timeout < 0)
		boa.impl_is_ready(null);
	    else
	    {
		try
		{
		    Thread.sleep(timeout * 1000);
		}
		catch(InterruptedException ex)
		{
		}
	    }
	    
	    //
	    // Disconnect the pull consumer here to stop the event
	    // service from pushing further events.
	    //
	    consumer.disconnect_pull_consumer();
	}
	catch(SystemException ex)
	{
	    ex.printStackTrace();
	    System.exit(1);
	}

	System.exit(0);
    }

    private static void
    usage()
    {
        System.out.println(
            "Usage: java event.PullServer [options]\n\n" +
	    "Options:\n" +
	    "-h, --help             Show this message.\n" +
	    "-s, --slow             Run in `slow' mode.\n" +
	    "-t sec, --timeout sec  Run for [sec] seconds, -1 forever.\n" +
	    "-n, --no-register      Don't register with the event service.\n");
    }
}

==> JOB-3.3.2.tar.gz: JOB-3.3.2/event/demo/PullServer.java <==
// **********************************************************************
//
// Copyright (c) 2000
// Object Oriented Concepts, Inc.
// Billerica, MA, USA
//
// All Rights Reserved
//
// **********************************************************************

package event;

import org.omg.CORBA.*;
import org.omg.CosEventChannelAdmin.*;
import java.io.*;
import java.util.*;

public class PullServer
{
    public static void
    main(String args[])
    {
	Properties props = System.getProperties();
	props.put("org.omg.CORBA.ORBClass", "com.ooc.CORBA.ORB");
	props.put("org.omg.CORBA.ORBSingletonClass",
		  "com.ooc.CORBA.ORBSingleton");

	try
	{
	    //
	    // Create ORB.
	    //
	    ORB orb = ORB.init(args, props);

	    //
	    // Filter options.
	    //
	    args = ((com.ooc.CORBA.ORB)orb).filter_options(args);
	    
	    //
	    // Create BOA.
	    //
	    BOA boa = ((com.ooc.CORBA.ORB)orb).BOA_init(args, props);

	    //
	    // Filter options.
	    //
	    args = ((com.ooc.CORBA.BOA)boa).filter_options(args);

	    ((com.ooc.CORBA.ORB)orb).conc_model(
		com.ooc.CORBA.ORB.ConcModel.ConcModelThreaded);
	    ((com.ooc.CORBA.BOA)boa).conc_model(
		com.ooc.CORBA.BOA.ConcModel.ConcModelThreadPerClient);

	    //
	    // Parse command line arguments.
	    //
	    boolean slow = false;
	    long timeout = 5;
	    boolean reg = true;
	    String channelName = null;
	    for(int i = 0; i < args.length; i++)
	    {
		if(args[i].equals("--help") || args[i].equals("-h"))
		{
		    usage();
                    System.exit(0);
		}
		else if(args[i].equals("-s") || args[i].equals("--slow"))
		{
		    slow = true;
		}
		else if(args[i].equals("-n") ||args[i].equals("--no-register"))
		{
		    reg = false;
		}
		else if(args[i].equals("-t") ||
			args[i].equals("--timeout"))
		{
		    if(i + 1 >= args.length)
		    {
			System.err.println("Argument expected for " + args[i]);
			System.exit(1);
		    }
		    try
		    {
			timeout = Long.parseLong(args[i+1]);
		    }
		    catch(NumberFormatException ex)
		    {
			System.err.println("Bad format for timeout: " +
					   args[i+1]);
			System.exit(1);
		    }
		    ++i;
		}
		else if(!args[i].startsWith("-"))
		{
		    channelName = args[i];
		}
		else
		{
		    System.err.println("Unknown option `" + args[i] + "'");
		    usage();
		    System.exit(1);
		}
	    }
	    
	    //
	    // Get event channel.
	    //
	    EventChannel e = GetEventChannel(orb, channelName);

	    //
	    // Create the servant
	    //
	    PullSupplier_impl supplier = new PullSupplier_impl(orb, boa, slow);

	    //
	    // Connect the supplier to the ORB with the same name each
	    // time.
	    //
	    ((com.ooc.CORBA.ORB)orb).connect(supplier, "DefaultSupplier");

	    ProxyPullConsumer consumer = null;
	    if(reg)
	    {
		//
		// Get ProxyPullConsumer.
		//
		SupplierAdmin supplierAdmin = e.for_suppliers();
		consumer = supplierAdmin.obtain_pull_consumer();
		try
		{
		    consumer.connect_pull_supplier(supplier);
		}
		catch(AlreadyConnected ex)
		{
		    ex.printStackTrace();
		    System.exit(1);
		}
		catch(TypeError ex)
		{
		    ex.printStackTrace();
		    System.exit(1);
		}
	    }

	    try
	    {
		if(timeout < 0)
		{
		    boa.impl_is_ready(null);
		}
		else
		{
		    ((com.ooc.CORBA.BOA)boa).init_servers();
		    try
		    {
			Thread.sleep(timeout * 1000);
		    }
		    catch(InterruptedException ex)
		    {
		    }
		}

		//
		// Disconnect the pull consumer here to stop the event
		// service from pushing further events.
		//
		if(reg)
		    consumer.disconnect_pull_consumer();
	    }
	    //
	    // Expected if ORB/Client has already been shutdown
	    //
	    catch(org.omg.CORBA.TRANSIENT ex)
	    {
	    }
	    catch(org.omg.CORBA.COMM_FAILURE ex)
	    {
	    }
	}
	catch(SystemException ex)
	{
	    ex.printStackTrace();
	    System.exit(1);
	}

	System.exit(0);
    }

    private static void
    usage()
    {
        System.out.println(
            "Usage: java event.PullServer [options] [channel-name]\n\n" +
	    "Options:\n" +
	    "-h, --help             Show this message.\n" +
	    "-s, --slow             Run in `slow' mode.\n" +
	    "-t sec, --timeout sec  Run for [sec] seconds, -1 forever.\n" +
	    "-n, --no-register      Don't register with the event service.\n");
    }

    static private EventChannel
    GetEventChannel(org.omg.CORBA.ORB orb, String name)
    {
	EventChannel e = null;
	if(name == null)
	{
	    //
	    // Get event channel from the initial reference.
	    //
	    try
	    {
		org.omg.CORBA.Object obj =
		    orb.resolve_initial_references("EventService");
		e = EventChannelHelper.narrow(obj);
	    }
	    catch(org.omg.CORBA.ORBPackage.InvalidName ex)
	    {
		System.err.println("can't resolve `EventService'");
		System.exit(1);
	    }
	    
	    if(e == null)
	    {
		System.err.println("`EventService' is not an EventChannel " +
				   " object reference");
		System.exit(1);
	    }
	}
	else
	{
	    //
	    // Get event channel factory. Note that this uses ORBacus
	    // proprietary methods.
	    //
	    com.ooc.OBEventChannelFactory.EventChannelFactory f = null;
	    try
	    {
		org.omg.CORBA.Object obj =
		    orb.resolve_initial_references("EventChannelFactory");
		f = com.ooc.OBEventChannelFactory.EventChannelFactoryHelper.
		    narrow(obj);
	    }
	    catch(org.omg.CORBA.ORBPackage.InvalidName ex)
	    {
		System.err.println("Can't resolve `EventChannelFactory'");
		System.exit(1);
	    }
	
	    if(f == null)
	    {
		System.err.println("`EventChannelFactory' is not an " +
				   "EventChannelFactory object reference");
		System.exit(1);
	    }

	    //
	    // Get event channel.
	    //
	    try
	    {
		e = f.get_channel_by_id(name);
	    }
	    catch(com.ooc.OBEventChannelFactory.ChannelNotAvailable ex)
	    {
		try
		{
		    e = f.create_channel(name);
		    System.err.println("`Channel " + name + "' created");
		}
		catch(com.ooc.OBEventChannelFactory.ChannelAlreadyExists ex1)
		{
		    System.err.println("Channel exists: try again");
		    System.exit(1);
		}
	    }
	}
	return e;
    }
}
